"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/plugin.ts
var plugin_exports = {};
__export(plugin_exports, {
  default: () => plugin
});
module.exports = __toCommonJS(plugin_exports);

// src/core.ts
var path = __toESM(require("path"));

// src/utils.ts
var fs = __toESM(require("fs"));
function parseEnvsFromFile(path2, force) {
  try {
    const source = fs.readFileSync(path2).toString();
    const res = source.split("\n").map((l) => l.trim()).filter((l) => {
      return !l.startsWith("#") && Boolean(l);
    }).map((l) => l.split("="));
    return Object.fromEntries(res);
  } catch {
    if (force) {
      return {};
    }
    throw new Error(`Cannot read or parse file '${path2}'`);
  }
}
function diffEnvs(source, target) {
  return Object.keys(source).reduce((acc, key) => {
    if (target[key]) {
      return acc;
    }
    acc[key] = source[key];
    return acc;
  }, {});
}
function appendEnvsToFile(path2, envs) {
  let res = fs.existsSync(path2) ? fs.readFileSync(path2).toString() : "";
  if (res.length && !res.endsWith("\n")) {
    res += "\n";
  }
  Object.keys(envs).forEach((key) => {
    res += `${key}=${envs[key]}
`;
  });
  fs.writeFileSync(path2, res);
}

// src/core.ts
async function compare(options) {
  const { source, target, ignoreKeys = [] } = options;
  const sourceEnvs = (typeof source === "string" ? [source] : source).reduce((acc, file) => {
    const filePath = path.resolve(file);
    const envs = parseEnvsFromFile(filePath);
    return Object.assign(acc, envs);
  }, {});
  const targetPath = path.resolve(target);
  const targetEnvs = parseEnvsFromFile(targetPath, true);
  ignoreKeys.forEach((key) => targetEnvs[key] = "_ignored");
  const diff = diffEnvs(sourceEnvs, targetEnvs);
  if (!Object.keys(diff).length) {
    return;
  }
  return appendEnvsToFile(targetPath, diff);
}

// src/plugin.ts
function plugin(options) {
  const { executionCondition = "serve" } = options;
  return {
    name: "env-comparison",
    config(_, { command }) {
      if (executionCondition === "both" || executionCondition === command) {
        compare(options);
      }
    }
  };
}
