// src/core.ts
import * as path from "path";

// src/utils.ts
import * as fs from "fs";
function parseEnvsFromFile(path2, force) {
  try {
    const source = fs.readFileSync(path2).toString();
    const res = source.split("\n").map((l) => l.trim()).filter((l) => {
      return !l.startsWith("#") && Boolean(l);
    }).map((l) => l.split("="));
    return Object.fromEntries(res);
  } catch {
    if (force) {
      return {};
    }
    throw new Error(`Cannot read or parse file '${path2}'`);
  }
}
function diffEnvs(source, target) {
  return Object.keys(source).reduce((acc, key) => {
    if (target[key]) {
      return acc;
    }
    acc[key] = source[key];
    return acc;
  }, {});
}
function appendEnvsToFile(path2, envs) {
  let res = fs.existsSync(path2) ? fs.readFileSync(path2).toString() : "";
  if (res.length && !res.endsWith("\n")) {
    res += "\n";
  }
  Object.keys(envs).forEach((key) => {
    res += `${key}=${envs[key]}
`;
  });
  fs.writeFileSync(path2, res);
}

// src/core.ts
async function compare(options) {
  const { source, target, ignoreKeys = [] } = options;
  const sourceEnvs = (typeof source === "string" ? [source] : source).reduce((acc, file) => {
    const filePath = path.resolve(file);
    const envs = parseEnvsFromFile(filePath);
    return Object.assign(acc, envs);
  }, {});
  const targetPath = path.resolve(target);
  const targetEnvs = parseEnvsFromFile(targetPath, true);
  ignoreKeys.forEach((key) => targetEnvs[key] = "_ignored");
  const diff = diffEnvs(sourceEnvs, targetEnvs);
  if (!Object.keys(diff).length) {
    return;
  }
  return appendEnvsToFile(targetPath, diff);
}

// src/plugin.ts
function plugin(options) {
  const { executionCondition = "serve" } = options;
  return {
    name: "env-comparison",
    config(_, { command }) {
      if (executionCondition === "both" || executionCondition === command) {
        compare(options);
      }
    }
  };
}
export {
  plugin as default
};
